==> psxc-imdb_v0.7.tgz: psxc-imdb/psxc-imdb-full.tcl <==
################################
# PSXC-IMDB bot-addon-full v0.1
# -----------------------------
# Tcl is really not my strong suit, so do not be surprised if your computer
# blows up when you run this script.
#
# This little thingy can be used instead of adding stuff to crontab. It does
# basically the same thing, only this will react instantly on .nfo uploads.
# It will also be used instead of your normal bot config to output stuff in
# (one) channel.
#
# edit the (not so) advanced config below, then copy this script to your bot's
# script directory and add the following to your eggdrop.conf:
#
#   source scripts/psxc-imdb-full.tcl
#

###################
##### config ######

# location of psxc-imdb.log file (aka IMDBLOG)
set psxc(IMDBLOG)     "/glftpd/ftp-data/logs/psxc-imdb.log"

# location of imdb-script.sh
set psxc(IMDBSCRIPT)  "/glftpd/bin/psxc-imdb.sh"

# location of psxc-moviedata.log file (aka GLLOG)
set psxc(IMDBMOVIE)   "/glftpd/ftp-data/logs/psxc-moviedata.log"

# announce-channel
set psxc(IMDBCHANNEL) "#pleasechange"

##### config done #####
#######################

proc readimdb {} {
 global psxc psxclog psxcmovie
 utimer 3 "readimdb"
 set logsize [file size $psxc(IMDBLOG)]
 if { $logsize == $psxclog } { return 0 }
 if { $logsize  < $psxclog } { set psxclog 0 }
 open |$psxc(IMDBSCRIPT)
 set psxclog [file size $psxc(IMDBLOG)]
 set moviesize [file size $psxc(IMDBMOVIE)]
 if { $moviesize == $psxcmovie } { return 0 }
 if { $moviesize  < $psxcmovie } { set psxcmovie 0 }
 if { [catch { set offset [open $psxc(IMDBMOVIE) r] } ] } { return 0 }
 seek $offset $psxcmovie
 while {![eof $offset]} {
  set line [gets $offset]
  if {$line == ""} {continue}
  set thr [lindex $line 7]
  putserv "PRIVMSG $psxc(IMDBCHANNEL) :$thr"
 }
 close $offset
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 return 0
}
set psxclog 0
set psxcmovie [file size $psxc(IMDBMOVIE)]
readimdb
putlog "Loaded: psxc-imdb bot-addon v0.1"

==> psxc-imdb_v1.1.tgz: psxc-imdb/psxc-imdb-full.tcl <==
################################
# PSXC-IMDB bot-addon-full v0.2
# -----------------------------
# Tcl is really not my strong suit, so do not be surprised if your computer
# blows up when you run this script.
#
# This little thingy can be used instead of adding stuff to crontab. It does
# basically the same thing, only this will react instantly on .nfo uploads.
# It will also be used instead of your normal bot config to output stuff in
# (one) channel.
#
# edit the (not so) advanced config below, then copy this script to your bot's
# script directory and add the following to your eggdrop.conf:
#
#   source scripts/psxc-imdb-full.tcl
#

###################
##### config ######

# location of psxc-imdb.log file (aka IMDBLOG)
set psxc(IMDBLOG)     "/glftpd/ftp-data/logs/psxc-imdb.log"

# location of imdb-script.sh
set psxc(IMDBSCRIPT)  "/glftpd/bin/psxc-imdb.sh"

# location of psxc-moviedata.log file (aka GLLOG)
set psxc(IMDBMOVIE)   "/glftpd/ftp-data/logs/psxc-moviedata.log"

# announce-channel
set psxc(IMDBCHANNEL) "#pleasechange"

##### config done #####
#######################

proc readimdb {} {
 global psxc psxclog psxcmovie
 utimer 3 "readimdb"
 set logsize [file size $psxc(IMDBLOG)]
 if { $logsize == $psxclog } { return 0 }
 if { $logsize  < $psxclog } { set psxclog 0 }
 set script $psxc(IMDBSCRIPT)
 set out [ exec $script]
 set psxclog [file size $psxc(IMDBLOG)]
 set moviesize [file size $psxc(IMDBMOVIE)]
 if { $moviesize == $psxcmovie } { return 0 }
 if { $moviesize  < $psxcmovie } { set psxcmovie 0 }
 if { [catch { set offset [open $psxc(IMDBMOVIE) r] } ] } { return 0 }
 seek $offset $psxcmovie
 while {![eof $offset]} {
  set line [gets $offset]
  if {$line == ""} {continue}
  set thr [lindex $line 7]
  putserv "PRIVMSG $psxc(IMDBCHANNEL) :$thr"
 }
 close $offset
 set psxcmovie [file size $psxc(IMDBMOVIE)]
 return 0
}
set psxclog 0
set psxcmovie [file size $psxc(IMDBMOVIE)]
readimdb
putlog "Loaded: psxc-imdb bot-addon v0.2"
